##### Meta #####

# Author: Andreas Hoehn
# Version: 1.0
# Date:  2024-06-07
# About: The Main Control File

# ---------------------------------------------------------------------------- #
# ---------------------------------------------------------------------------- #

### Preparation ###

# clean workspace
rm(list = ls())  # remove all objects from work space 
gc(full = TRUE)  # deep clean garbage
dir()

# ---------------------------------------------------------------------------- #
# ---------------------------------------------------------------------------- #

### Libraries ###

# List of Required Packages 
RequiredPackages <- c("here", "readxl",                  # Folders/ Loading
                      "data.table",                      # Dialect 
                      "ggplot2",                         # Data Visualization
                      "maps","rgeos","rgdal","maptools", # Mapping
                      "rmarkdown","tinytex","knitr")     # Report 

# ensure all packages are installed and loaded 
.EnsurePackages <- function(packages_vector) {
  new_package <- packages_vector[!(packages_vector %in% 
                                     installed.packages()[, "Package"])]
  if (length(new_package) != 0) {
    install.packages(new_package) }
  sapply(packages_vector, suppressPackageStartupMessages(require),
         character.only = TRUE)
}
.EnsurePackages(RequiredPackages)
here <- here::here # in order to ensure correct file paths 

# ---------------------------------------------------------------------------- #
# ---------------------------------------------------------------------------- #

### Definitions ###

# initialize ...
definitions <- list()

# run download from online yes/no 
definitions$run_queries <- FALSE

# options: display format of numbers and timeout for downloads
definitions$scipen  <- 1e4
definitions$timeout <- 1e4

# US Wave, Geo Subset for Overall Validation, Geo Subset for Spatial Plots
definitions$us_wave     <- "k"                                      # don't change
definitions$geo_subset  <- c("E","S","W")                           # all of GB

# Plots in Report: Size and Colour Schemes
definitions$fig_width  <- 25  # = width of output figures in cm
definitions$fig_height <- 15  # = height of output figures in cm
definitions$map_cols   <- colorRampPalette(c("#BB650B","#F5F5DC","#2E8B57"))(3)
definitions$sep_cols   <- c("#BB650B","#2E8B57")
definitions$sep_alpha  <- 0.25
definitions$dot_alpha  <- 0.50
definitions$supp_col   <- c("#000000")
definitions$fit_col    <- c("#FF0000")

# Rounding in Report: 
definitions$round <- 3

# ---------------------------------------------------------------------------- #
# ---------------------------------------------------------------------------- #

### Internal Diagnostics Stats List Object ###

# initialize ...
diagnostics <- list()
diagnostics$unmatched_areas_lookup <- c()      #  to be filled 
diagnostics$unmatched_areas_constraints <- c() #  to be filled 
diagnostics$N_total_constraints <- c()         #  to be filled 

# ---------------------------------------------------------------------------- #
# ---------------------------------------------------------------------------- #

### Supp Functions ###

# Splits the  Screen in 2 halves 45*
.SPlitPlot45  <- function(x){y = x; return(y) }

# ---------------------------------------------------------------------------- #
# ---------------------------------------------------------------------------- #

### Source Code ###

# apply options
options(scipen  = definitions$scipen, timeout = definitions$timeout)

# Benchmark Run Time: START #
benchmark_time <- list() 
benchmark_time$start <- Sys.time()

# Validation File 
source(here::here("RCode","02_load_link_data.R"))
source(here::here("RCode","03_internal_validation_sp_with_health.R"))
source(here::here("RCode","04_external_validation.R"))

# Benchmark Run Time: END #
benchmark_time$end <- Sys.time()

# ---------------------------------------------------------------------------- #
# ---------------------------------------------------------------------------- #